package
Version:
v0.0.0-...-9fcd9d5
Opens a new window with list of versions in this module.
Published: Oct 17, 2022
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type User struct {
Username string `json:"username" bson:"username"`
Name string `json:"name" bson:"name"`
Email string `json:"email" bson:"email"`
Password string `json:"password" bson:"password"`
Ip string `json:"ip" bson:"ip"`
DeletedAccount int64 `json:"deleted" bson:"deleted"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.