package
Version:
v0.0.0-...-9fcd9d5
Opens a new window with list of versions in this module.
Published: Oct 17, 2022
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Question struct {
Type string `json:"type" bson:"type"`
Question string `json:"question" bson:"question"`
Media string `json:"media" bson:"media"`
Answers map[int]string `json:"answers" bson:"answers"`
}
type Quiz struct {
Id string `json:"id" bson:"id"`
Owner string `json:"username" bson:"username"`
Name string `json:"name" bson:"name"`
Questions map[string]Question `json:"questions" bson:"questions"`
Solutions map[string]int `json:"solutions" bson:"solutions"`
}
type Result struct {
Id string `json:"id" bson:"id"`
Username string `json:"username" bson:"username"`
Date time.Time `json:"date" bson:"date"`
Answers map[string]int `json:"answers" bson:"answers"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.